library(shiny)
library(startR)
library(s2dverification)
library(multiApply)

shinyServer(function(input, output) {

  dataInput <- reactive({
    Load(input$var, input$exp, input$obs, gsub('-', '', input$sdates), 
         lonmin = input$lon_range[1], lonmax = input$lon_range[2],
         latmin = input$lat_range[1], latmax = input$lat_range[2],
         leadtimemin = input$ftime_range[1],
         leadtimemax = input$ftime_range[2],
         nmember = input$nmember[1],
         grid = input$grid, output = 'lonlat')
  })
  
  output$equiMapExp <- renderPlot({
    input$checkButton
    data <- isolate(dataInput())

    PlotLayout(PlotEquiMap, c('lat', 'lon'),
               data$mod, data$lon, data$lat, toptitle = input$exp,
               brks = 100, units = attr(data$Variable, 'units'),
               fill = FALSE)
  })

  output$equiMapExpMean <- renderPlot({
    input$checkButton
    data <- isolate(dataInput())
    ensemble_mean <- Apply(data$mod, target_dims = c('member'), fun = mean)$output1

    PlotLayout(PlotEquiMap, c('lat', 'lon'), 
               ensemble_mean, data$lon, data$lat, toptitle = paste(input$exp, 'ensemble mean'),
               brks = 100, units = attr(data$Variable, 'units'),
               fill = FALSE)

  })

  output$equiMapObs <- renderPlot({
    input$checkButton
    data <- isolate(dataInput())
    PlotLayout(PlotEquiMap, c('lat', 'lon'), 
               data$obs, data$lon, data$lat, toptitle = input$obs,
               brks = 100, units = attr(data$Variable, 'units'),
               fill = FALSE) 
               #brks = colorbar$brks, cols = colorbar$cols,
               #col_inf = colobrar$col_inf, col_sup = colorbar$col_sup)
  })
})
